(function (exports) {
'use strict';

// -- Akamai Identity Services - Client Object
// -- Version 2.7.2013.10.10 for AIS v3.1.16.2

(function () {
  // Public Dispatcher (for JSONP)
  function aisresponse(resp, is_cached) {
    // If using a different responsefield, this must be changed
    window.ais_client.aisresponse(resp);
    window.ais_client.log("aisresponse: Response Data" + (is_cached == true ? " (cache) " : ""), true);
    window.ais_client.log(resp);
  }

  // AIS Client object
  function ais_client() {
    this.callbacks = {
      "bounce": this._nullhandler,
      "echo_response": this._nullhandler,
      "chooser": this._nullhandler,
      "init": this._nullhandler,
      "identity": this._nullhandler,
      "logout_result": this._nullhandler,
      "becomes_authenticated": this._nullhandler,
      "becomes_unauthenticated": this._nullhandler,
      "authz_query": this._nullhandler,
      "resources": this._nullhandler,
      "device": this._nullhandler,
      "vcs": this._nullhandler,
      "vcs_list": this._nullhandler,
      "authz_query_list": this._nullhandler
    };
    this.baseurl = 'idp.securetve.com/rest/1.0/'; //'http://idp.securetve.com/rest/1.0/';
    this.responsefield = 'aisresponse'; // NOTE: If this is changed, must also change name of public dispatcher (above) and all instances of "aisresponse" in the code below
    this.authstate = false; // Only 2 states, all transitions allowed
    this.platform_id = ''; // SP platform_id/configuration
    this.aisuid = ''; // Akamai Identity Services - Identity ID
    this.use_logging = false;
    this.log_target = ''; // Page element name for HTML log output
    this.use_cache = true; // Usecache flag (default true, not used at this time)
    this.response_cache = {}; // Internal JS response cache
    this.cache_time = { "init": 30000, "chooser": 30000, "authz_query": 30000, "identity": 30000, "bounce": 2000, "echo_response": 30000, "vcs": 2000, "vcs_list": 5000, "resources": 30000, "authz_query_list": 30000 }; // Default internal JS resopnse cache settings
    this.script_insert_type = ''; // Use default or jquery
    this.log_toggle = 0; // for alternating color lines for log
    this.supportsLocalStorage = undefined; // Check if localstorage is supported (Added 11/26)
    this.ls_prepend = 'AIS_client___'; //Prepend for LocalStorage keys
    this.language_override = '';
    this.protocol = window.location.protocol == 'http:' || window.location.protocol == 'https:' ? window.location.protocol + '//' : 'http://';
    this.log_object = {}; //[];
    this.log_object_keys = [];
    this.log_object_size = 20;
  }

  //////////////////////////////////////////
  // Public interface
  //////////////////////////////////////////

  // AIS Client - Public Interface
  ais_client.prototype.assignhandler = function (type, handler) {
    if (this._isFunction(handler)) {
      this.callbacks[type] = handler;
    } else {
      this.log("unable to assign handler to callback type (" + type + ") because it is not callable", true);
    }
  };

  ais_client.prototype.setPlatformId = function (platform_id) {
    if (this.platform_id != platform_id) {
      this._reset_cache(true);
    }
    this.platform_id = platform_id;
    this.log('setPlatformId (' + this.platform_id + ')', true);
  };

  ais_client.prototype.setLanguageOverride = function (language_code) {
    // ADDED 3.1.16.2 7/24/2013
    this.language_override = language_code;
    this.log('setLanguageOverride (' + this.language_override + ')', true);
  };

  //** ADD TO TEST HARNESS PAGE
  ais_client.prototype.setProtocol = function (protocol) {
    // ADDED 3.1.16.2 8/22/2013
    this.protocol = protocol;
    this.log('setProtocol (' + this.protocol + ')', true);
  };

  //** ADD TO TEST HARNESS PAGE
  ais_client.prototype.setResponsefield = function (responsefield) {
    // ADDED 3.1.16.2 8/27/2013
    this.responsefield = responsefield;
    this.log('setResponsefield (' + this.responsefield + ')', true);
  };

  ais_client.prototype.aisresponse = function (resp) {
    // capture any state transition messages that impact the type of callback issued
    // Auth N
    if (resp['authenticated'] !== undefined && this.authstate !== this._mkboolean(resp['authenticated'])) {
      // AuthN state has transitioned
      this.authstate = this._mkboolean(resp['authenticated']);
      this._reset_cache(); // Clear Response Cache
      //  Dispatch Events
      if (this.authstate) {
        this.log("Authenticated", true);
        this._dispatch('becomes_authenticated', resp);
      } else {
        this.log("Not Authenticated", true);
        this._dispatch('becomes_unauthenticated', resp);
      }
    }

    // AuthZ
    if (resp['authorization'] !== undefined) {
      // AuthZ state has transitioned
      if (this._mkboolean(resp['authorization'])) {
        this.log("Authorized: " + resp['resource'], true);
      } else {
        this.log("Not Authorized: " + resp['resource'], true);
      }
    }

    // AISUID (Identity, Init)
    if (resp['aisuid'] !== undefined) {
      this.aisuid = resp['aisuid']; // Get & Store AISUID
      this.log("Init: AISUID - " + this.aisuid, true);
    } else if (resp['identity'] !== undefined) {
      this.aisuid = resp['identity']['aisuid']; // Get & Store AISUID
      this.log("Identity: AISUID - " + this.aisuid, true);
    }

    this._set_cache(resp); // Set Response Cache to Response data

    // FOR "LIST" Responses (VCS, AuthZ)
    if (resp['_type'] == 'authz_query_list' || resp['_type'] == 'vcs_list') {
      // ADDED 7/24/2013, updated 10/2013
      for (var i = 0; i < resp['documents'].length; i++) {
        this._set_cache(resp['documents'][i]);
      }
    }

    if (resp['_type'] == 'logout_result') {
      this.log("aisresponse: clearing cache", true);
      this._reset_cache(true);
    }

    // Dispatch Events
    var type = resp['_type'];
    this._dispatch(type, resp);
  };

  // AIS Client Public Interface - Direct API Calls
  ais_client.prototype.bounce = function (force) {
    this.log("bounce ", true);
    if (force == true || this._use_cache('bounce') == false) {
      this._call_ais('bounce');
    }
  };

  ais_client.prototype.echo = function (message, force) {
    this.log("echo ", true);
    if (force == true || this._use_cache('echo_response', message) == false) {
      this._call_ais('echo', message);
    }
  };

  ais_client.prototype.init = function (force) {
    this.log("init: (" + (this.authstate == true ? 'init' : 'chooser') + ")", true);
    if (force == true || this._use_cache(this.authstate == true ? 'init' : 'chooser') == false) {
      this._call_ais('init');
    }
  };

  ais_client.prototype.chooser = function (force) {
    this.log("chooser ", true);
    if (force == true || this._use_cache('chooser') == false) {
      this._call_ais('chooser');
    }
  };

  //init_increaseScope DEPRECATED as of 7/2012 (underlying API no longer available), use chooser
  ais_client.prototype.init_increaseScope = function (force) {
    this.log("init_increaseScope DEPRECATED, using chooser", true);
    if (force == true || this._use_cache('chooser') == false) {
      this._call_ais('chooser');
    }
  };

  ais_client.prototype.identity = function (force) {
    this.log("identity ", true);
    if (force == true || this._use_cache('identity') == false) {
      this._call_ais('identity');
    }
  };

  //logout SHOULD NOT BE USED as of 9/25/2012, use logoutFormat + call in page
  ais_client.prototype.logout = function () {
    this.log("logout ", true);
    this._reset_cache(); // Clear Response Cache on logout
    this._call_ais('logout');
  };

  ais_client.prototype.resourceAccess = function (resourceid, force) {
    //NEW AS OF AIS v3.1.10 7/2012
    this.log("resourceAccess: " + resourceid, true);
    if (force == true || this._use_cache('authz_query', resourceid) == false) {
      this._call_ais('resourceAccess', resourceid);
    }
  };

  ais_client.prototype.resourceAccessList = function (resourceid_array, force) {
    //NEW AS OF AIS v3.1.16.2 7/2013
    this.log("resourceAccessList: " + resourceid_array.join(','), true);
    if (resourceid_array == undefined || (typeof resourceid_array === "undefined" ? "undefined" : babelHelpers.typeof(resourceid_array)) != 'object') {
      this.log("resourceAccessList: no resourceid_array provided" + ((typeof resourceid_array === "undefined" ? "undefined" : babelHelpers.typeof(resourceid_array)) != 'object'), true);
    } else if (force == true || this._use_cache('authz_query_list', resourceid_array) == false) {
      this._call_ais('resourceAccessList', resourceid_array);
    } else {}
  };

  //channelAccess DEPRECATED as of 7/2012 (underlying API still available), use resourceAccess
  ais_client.prototype.channelAccess = function (channelid, force) {
    this.log("channelAccess: " + channelid, true);
    if (force == true || this._use_cache('authz_query', channelid) == false) {
      this._call_ais('channelAccess', channelid);
    }
  };

  ais_client.prototype.resources = function (force) {
    //NEW AS OF AIS v3.1.11 7/2012
    this.log("resources ", true);
    if (force == true || this._use_cache('resources') == false) {
      this._call_ais('resources');
    }
  };

  ais_client.prototype.registerDevice = function (shortcode) {
    //NEW AS OF AIS v3.1.13 8/2012
    this.log("registerDevice ", true);
    this._call_ais('registerDevice', shortcode);
  };

  ais_client.prototype.vcsGet = function (contentid, force) {
    this.log("vcsGet: " + contentid, true);
    if (contentid == undefined || contentid == '') {
      this.log("vcsGet: no contentid provided", true);
    } else if (force == true || this._use_cache('vcs', contentid) == false) {
      this._call_ais('vcsGet', contentid);
    }
  };

  ais_client.prototype.vcsSet = function (contentid, ph_pos) {
    this.log("vcsSet: " + contentid + "," + ph_pos, true);
    this._call_ais('vcsSet', contentid, ph_pos);
  };

  ais_client.prototype.vcsList = function (contentid_array, force) {
    //NEW AS OF AIS 3.1.15 11/2012, modified 10/2013
    this.log("vcsList: " + (contentid_array != undefined ? contentid_array.join(',') : 'no contentid_array'), true);
    if (force == true || this._use_cache('vcs_list', contentid_array) == false) {
      this._call_ais('vcsList', contentid_array);
    } else {}
  };

  ais_client.prototype.vcsListRecent = function (limit, force) {
    //NEW AS OF AIS 3.1.16.2 10/2013 for implicit/recent
    this.log("vcsListRecent: " + limit, true);
    if (force == true || this._use_cache('vcs_list', limit) == false) {
      this._call_ais('vcsListRecent', limit);
    }
  };

  // AIS Client Public Interface - Other Available methods
  ais_client.prototype.loginFormat = function (idp_platformid, response_target) {
    //Updated AIS 3.1.16.2 7/2013, added language, updated 10/2013
    return this.protocol + this.baseurl + this.platform_id + "/init/" + idp_platformid + "?responsemethod=redirect&format=jsonp" + (response_target != undefined && response_target != '' ? '&responsetarget=' + response_target : '') + (this.language_override != '' ? '&lang=' + this.language_override : '');
  };

  // Added 9/25/2012
  ais_client.prototype.logoutFormat = function (response_target) {
    return this.protocol + this.baseurl + this.platform_id + "/slo/?responsemethod=redirect&format=jsonp" + (response_target != undefined ? '&responsetarget=' + response_target : '');
  };

  // DEPRECATED - Use loginFormat instead
  ais_client.prototype.login = function (platformid) {
    this.log('ais_client.login DEPRECATED. Use ais_client.loginFormat instead.', true);
    return this.protocol + this.baseurl + this.platform_id + "/init/" + platformid + "?format=jsonp";
  };

  ais_client.prototype.setLogging = function (bool, page_element) {
    if (bool == true) {
      this.use_logging = bool;
      this.log('setLogging: Logging enabled (' + (page_element != undefined && document.getElementById(page_element) ? 'HTML - ' + page_element : 'console.log') + ')', true);
    } else {
      this.log('setLogging: Logging disabled', true);
      this.use_logging = bool;
    }
    if (page_element != undefined) {
      if (document.getElementById(page_element)) {
        this.log_target = page_element;
      }
    } else {
      this.log_target = '';
    }
  };

  ais_client.prototype.setCacheTime = function (call, cache_time) {
    var return_val = false;
    if (typeof cache_time == 'number') {
      switch (call) {
        case 'init':
        case 'chooser':
        case 'authz_query':
        case 'identity':
        case 'bounce':
        case 'echo_response':
        case 'vcs':
        case 'resources':
        case 'vcs_list':
        case 'authz_query_list':
          this.cache_time[call] = cache_time;
          return_val = true;
          break;
      }
    }
    this.log('setCache (' + call + ',' + cache_time + ') ' + (return_val == true ? 'changed successfully' : 'invalid call'), true);
    this.log(this.cache_time);
    return return_val;
  };

  ais_client.prototype.setUseCache = function (bool) {
    if ((bool == true || bool == false) && bool != this.use_cache) {
      this.use_cache = bool;
      this.log('setUseCache: changed to (use_cache=' + bool + ')', true);
    }
    this.log('setUseCache: (use_cache=' + this.use_cache + ')', true);
  };

  ais_client.prototype.setScriptInsert = function (insert_type) {
    this.script_insert_type = '';
    if (insert_type == 'jquery') {
      this.script_insert_type = insert_type;
    }
    this.log('setScriptInsert (' + insert_type + ')', true);
  };

  ais_client.prototype.setRedirectLocation = function (redirect_location) {
    this.log('setRedirectLocation (' + redirect_location + ')', true);
    this._set('ais_client_redirect_location', redirect_location);
  };

  ais_client.prototype.getRedirectLocation = function () {
    this.log('getRedirectLocation (' + this._get('ais_client_redirect_location') + ')', true);
    return this._get('ais_client_redirect_location');
  };

  ais_client.prototype.clearRedirectLocation = function () {
    this._clear('ais_client_redirect_location');
    this.log('clearRedirectLocation', true);
  };

  ais_client.prototype.log = function (str, prepend) {
    var log_message = "";
    if (prepend == true) {
      log_message = "[AIS] " + str;
    } else {
      log_message = str;
    }
    if (this.log_object_keys.length >= this.log_object_size) {
      var first_log_key = this.log_object_keys.shift();
      delete this.log_object[first_log_key];
    }
    var d = new Date();
    var log_key = d.getFullYear() + '-' + d.getMonth() + '-' + d.getDate() + ' ' + d.getHours() + ':' + d.getMinutes() + ':' + d.getSeconds() + '.' + d.getMilliseconds();
    this.log_object[log_key] = log_message;
    this.log_object_keys[this.log_object_keys.length] = log_key;
    if (this.use_logging == true) {
      if (window.console && console.log) {
        console.log(log_message);
      }
      if (this.log_target != '') {
        var object_output = '';
        if ((typeof str === "undefined" ? "undefined" : babelHelpers.typeof(str)) == 'object') {
          object_output += '<br>';
          object_output += this._create_object_log_output(str); //JSON.stringify(str);
          log_message = '[AIS] ' + log_message + object_output;
        }
        //document.getElementById(this.log_target).innerHTML += '<div style="border-collapse: collapse; border-width: 1px 0 1px 0; border-style: solid; border-color: #F;">'+log_message+'</div>';
        document.getElementById(this.log_target).innerHTML += '<div' + (this.log_toggle == 0 ? '' : ' style="background: #E8E8E8;"') + '>' + log_message + '</div>';
        this.log_toggle = this.log_toggle == 1 ? 0 : 1;
      }
    }
  };

  //////////////////////////////////////////
  // Private interface
  //////////////////////////////////////////
  ais_client.prototype._call_ais = function (call, extra, extra2) {
    var url = this.protocol + this.baseurl + this.platform_id;
    if (call == 'echo') {
      url += "/echo/" + extra;
    } else if (call == 'bounce') {
      url += "/bounce/";
    } else if (call == 'init') {
      url += "/init/";
    } else if (call == 'chooser') {
      url += "/chooser/";
      //} else if (call == 'init_increaseScope') {  //DEPRECATED, USE chooser
      //  url += "/init/increaseScope";        //DEPRECATED, USE chooser
    } else if (call == 'identity') {
      url += "/identity/";
      //    } else if (call == 'logout') {
      //    url += "/slo/";
    } else if (call == 'resourceAccess') {
      //ADDED AS OF AIS v3.1.10 7/2012
      url += "/identity/resourceAccess/" + extra;
    } else if (call == 'channelAccess') {
      //TO BE DEPRECATED, USE resourceAccess
      url += "/identity/channelAccess/" + extra; //TO BE DEPRECATED, USE resourceAccess
    } else if (call == 'resources') {
      //ADDED AS OF AIS v3.1.11 7/2012
      url += "/identity/resourceAccess/";
    } else if (call == 'registerDevice') {
      //ADDED AS OF AIS v3.1.13 8/2012
      url += "/identity/registerDevice/" + extra;
    } else if (call == 'vcsGet') {
      url += "/vcs/" + extra;
    } else if (call == 'vcsList') {
      //ADDED AS OF AIS v3.1.15 11/2012
      url += "/vcs/";
    } else if (call == 'vcsListRecent') {
      //ADDED AS OF AIS 3.1.16.2 10/2013
      url += "/vcs/";
    } else if (call == 'vcsSet') {
      url += "/vcs/" + extra;
    } else if (call == 'resourceAccessList') {
      //ADDED AS OF AIS v3.1.16.2 7/2013
      url += "/identity/resourceAccess/";
    }
    url += "?format=jsonp" + "&responsefield=" + this.responsefield;

    if (call == 'vcsSet') {
      url += "&ph_pos=" + extra2 + "&trickmode=post";
    }
    if (call == 'vcsList' && extra != undefined && extra != null && extra != '') {
      url += "&content_id=" + extra.join('&content_id=');
    }
    if (call == 'vcsListRecent' && extra != undefined && extra != null && extra != '') {
      //ADDED AS OF AIS 3.1.16.2 10/2013
      url += "&limit=" + extra;
    }
    if (call == 'resourceAccessList') {
      //ADDED AS OF AIS v3.1.16.2 7/2013
      url += "&resource_id=" + extra.join('&resource_id=');
    }
    if (this.language_override != '' && (call == 'resourceAccess' || call == 'channelAccess' || call == 'resourceAccessList')) {
      url += "&lang=" + this.language_override;
    }

    this.log(call + ': ' + url, true);
    if (this.script_insert_type == 'jquery') {
      // Use jQuery AJAX
      (function ($) {
        $.ajax({
          url: url,
          dataType: "script",
          cache: true,
          async: true
        });
      })(jQuery);
    } else {
      // Use dynamic script insertion
      var script = document.createElement('script');
      script.setAttribute('src', url);
      document.getElementsByTagName('head')[0].appendChild(script);
    }
  };

  ais_client.prototype._mkboolean = function (val) {
    return (/^true$/i.test(val)
    );
  };

  ais_client.prototype._isFunction = function (x) {
    return !!x && x.constructor == Function;
  };

  // Handler to ignore the response
  ais_client.prototype._nullhandler = function (type, resp) {};

  ais_client.prototype._alerthandler = function (type, resp) {
    alert("alert handler received message of type: " + type + "\n with: " + resp, true);
  };

  ais_client.prototype._dispatch = function (type, resp) {
    if (this.callbacks[type] !== undefined && this._isFunction(this.callbacks[type])) {
      var runner = this.callbacks[type];
      runner(type, resp);
    } else {
      this.log("callable is not set for handler: " + type, true);
    }
  };

  // For Logging
  ais_client.prototype._create_object_log_output = function (resp) {
    var output_value = '';
    output_value = '{';
    for (var key in resp) {
      if (babelHelpers.typeof(resp[key]) == 'object') {
        output_value += '' + (typeof key == 'string' ? '"' + key + '"' : key) + ':';
        output_value += this._create_object_log_output(resp[key]);
        output_value += ', ';
      } else {
        output_value += '' + (typeof key == 'string' ? '"' + key + '"' : key) + ':' + (typeof resp[key] == 'string' ? '"' + resp[key] + '"' : resp[key]) + ', ';
      }
    }
    output_value = output_value.substring(0, output_value.length - 2);
    output_value += '}';
    return output_value;
  };

  // For Response Cache
  ais_client.prototype._use_cache = function (call) {
    var return_val = false;
    if (this.use_cache == false) {
      this.log("_use_cache: caching disabled", true);
      return return_val;
    }
    var last_update = 0;
    var cache_type = '';
    var d = new Date();
    var response_call = call; //var response_call = ( (call == 'authz_query')?call+"-"+arguments[1] : call );
    if (response_call == 'authz_query' || response_call == 'vcs') {
      response_call += "-" + arguments[1];
    } else if (response_call == 'echo_response') {
      response_call += "-" + escape(arguments[1]);
    } else if (response_call == 'vcs_list') {
      response_call += "-" + (babelHelpers.typeof(arguments[1]) != 'object' ? arguments[1] : arguments[1].join('-')); //UPDATED 10/2013 implicit vs explicit
    }
    var localStorage_responseCacheUpdate = undefined;
    if (this.supportsLocalStorage == true) {
      localStorage_responseCacheUpdate = localStorage.getItem(this.ls_prepend + this.platform_id + '__' + 'response_cache_update__' + response_call);
    }
    if (this.response_cache['_response_cache_updates'][response_call] !== undefined) {
      last_update = this.response_cache['_response_cache_updates'][response_call];
      cache_type = 'js';
    } else if (localStorage_responseCacheUpdate != undefined) {
      last_update = localStorage_responseCacheUpdate;
      cache_type = 'localStorage';
    }
    if (last_update > 0 && d.getTime() - last_update < this.cache_time[call]) {
      if (cache_type == 'js') {
        window[this.responsefield + '(this.response_cache[response_call],true)']; //Added 8/27/13
        //aisresponse(this.response_cache[response_call],true);  // If using a different responsefield, this must be changed
      } else if (cache_type == 'localStorage') {
        window[this.responsefield + '(JSON.parse(localStorage.getItem(this.ls_prepend+this.platform_id+"__"+response_call)),true)']; //Added 8/27/13
        //aisresponse(JSON.parse(localStorage.getItem(this.ls_prepend+this.platform_id+'__'+response_call)),true);  // If using a different responsefield, this must be changed (added 11/26)
      }
      return_val = true;
      this.log("_use_cache: " + response_call + " (" + cache_type + " cached " + (this.cache_time[call] - (d.getTime() - last_update)) + "/" + this.cache_time[call] + ")", true);
    } else {
      return_val = false;
      //clear local storage
      if (this.supportsLocalStorage == true) {
        localStorage.removeItem(this.ls_prepend + this.platform_id + '__' + 'response_cache_update__' + response_call);
        localStorage.removeItem(this.ls_prepend + this.platform_id + '__' + response_call);
      }
    }
    return return_val;
  };

  // For Response Cache
  ais_client.prototype._set_cache = function (resp) {
    var d = new Date();
    var response_type = resp['_type']; //var response_type = ((resp['_type'] == 'authz_query')? resp['_type']+"-"+resp['resource'] : resp['_type']);
    if (response_type == 'authz_query') {
      response_type = resp['_type'] + "-" + resp['resource'];
    } else if (response_type == 'echo_response') {
      response_type += "-" + escape(resp['response_value']);
    } else if (response_type == 'vcs') {
      response_type += "-" + escape(resp['content_id']);
    } else if (response_type == 'vcs_list') {
      for (var i = 0; i < resp['documents'].length; i++) {
        response_type += "-" + resp['documents'][i].content_id;
      }
    }
    if (this.response_cache[response_type] === undefined || d.getTime() - this.response_cache['_response_cache_updates'][response_type] > this.cache_time[resp['_type']]) {
      var localStorage_responseCacheUpdate = undefined;
      if (this.supportsLocalStorage == true) {
        localStorage_responseCacheUpdate = localStorage.getItem(this.ls_prepend + this.platform_id + '__' + 'response_cache_update__' + response_type);
      }
      if (localStorage_responseCacheUpdate != undefined) {
        this.response_cache['_response_cache_updates'][response_type] = localStorage_responseCacheUpdate;
      } else {
        this.response_cache['_response_cache_updates'][response_type] = d.getTime();
      }
      if (this.supportsLocalStorage == true) {
        // 11/27
        localStorage.setItem(this.ls_prepend + this.platform_id + '__' + 'response_cache_update__' + response_type, d.getTime()); // 11/27
      }
    }
    this.response_cache[response_type] = resp;
    if (this.supportsLocalStorage == true) {
      // 11/27
      localStorage.setItem(this.ls_prepend + this.platform_id + '__' + response_type, JSON.stringify(resp));
    }
    //LOGGING
    this.log('_set_cache: ' + response_type + ' (caching length = ' + this.cache_time[resp['_type']] + ')', true);
    this.log(this.response_cache);
  };

  // For Response Cache
  ais_client.prototype._reset_cache = function (clearLocalStorage) {
    this.response_cache = { "_response_cache_updates": {} };
    if (clearLocalStorage == true && this.supportsLocalStorage == true) {
      // (added 11/26)
      var keyArray = [];
      for (var i = 0; i <= localStorage.length - 1; i++) {
        keyArray[i] = localStorage.key(i);
      }
      var ls_prefix = this.ls_prepend + this.platform_id + '__';
      for (var i = 0; i <= keyArray.length - 1; i++) {
        if (keyArray[i].substring(0, ls_prefix.length) == ls_prefix) {
          this.log('_reset_cache: Removing| ' + keyArray[i], true);
          localStorage.removeItem(keyArray[i]);
        }
      }
    }
  };

  ais_client.prototype._set = function (key, value) {
    if (this.supportsLocalStorage == true) {
      // use HTML5 local storage
      this.log('_set: using localStorage (key: "' + key + '", value: "' + value + '")', true);
      localStorage.removeItem(key);
      return localStorage.setItem(key, escape(value));
    } else {
      // use cookies
      var expires = "";
      if (arguments[2]) {
        var d = new Date();
        d.setTime(d.getTime() + arguments[2] * 24 * 60 * 60 * 1000);
        expires = "; expires=" + d.toGMTString();
      }
      document.cookie = key + "=" + escape(value) + expires + "; path=/";
      this.log('_set: using cookies (key: "' + key + '", value: "' + value + '", expires: "' + expires + '", cookie_value: "' + key + "=" + value + expires + "; path=/" + '")', true);
      return;
    }
  };
  ais_client.prototype._get = function (key) {
    if (this.supportsLocalStorage == true) {
      this.log('_get: using localStorage (key: "' + key + '", value: "' + localStorage.getItem(key) + '")', true);
      return unescape(localStorage.getItem(key));
    } else {
      var keyEQ = key + "=";
      var ca = document.cookie.split(';');
      for (var i = 0; i < ca.length; i++) {
        var c = ca[i];
        while (c.charAt(0) == ' ') {
          c = c.substring(1, c.length);
        }
        if (c.indexOf(keyEQ) == 0) {
          this.log('_get: using cookies (key: "' + key + '", value: "' + c.substring(keyEQ.length, c.length) + '")', true);
          return unescape(c.substring(keyEQ.length, c.length));
        }
      }
      return null;
    }
  };
  ais_client.prototype._clear = function (key) {
    if (this.supportsLocalStorage == true) {
      localStorage.removeItem(key);
    } else {
      this._set(key, "", -1);
    }
  };

  // Added 11/26
  ais_client.prototype._setLocalStorageSupport = function () {
    this.supportsLocalStorage = this.__checkLocalStorageSupport();
  };

  // Added 11/26
  ais_client.prototype.__checkLocalStorageSupport = function () {
    try {
      JSON.stringify({ "a": "b" });
      return 'localStorage' in window && window['localStorage'] !== null;
    } catch (e) {
      return false;
    }
  };

  // AIS Client - Initialization
  window.aisresponse = aisresponse;
  window.ais_client = new ais_client();
  window.ais_client._reset_cache();
  window.ais_client._setLocalStorageSupport();
  // AIS Client - JavaScript code ends here
})();

var AIS = function (_akamai$amp$AuthPlugi) {
  babelHelpers.inherits(AIS, _akamai$amp$AuthPlugi);

  function AIS(player, config) {
    babelHelpers.classCallCheck(this, AIS);

    var _this = babelHelpers.possibleConstructorReturn(this, (AIS.__proto__ || Object.getPrototypeOf(AIS)).call(this, player, config));

    _this.client = window.ais_client;
    _this.client.setLogging(_this.debug); // Enable AIS logging, log to console.log
    _this.client.setPlatformId(_this.config.platformId); // Set AIS platform_id
    _this.client.setUseCache(_this.config.useCache === true);

    // setup media transform
    if (_this.config.transform !== false) {
      _this.player.addTransform(akamai.amp.TransformType.MEDIA, { transform: _this.mediaTransform.bind(_this), priority: 1 });
    }
    return _this;
  }

  babelHelpers.createClass(AIS, [{
    key: "mediaTransform",
    value: function mediaTransform(media) {
      var _this2 = this;

      var status = media.status;
      if (this.player.security.authorized === true) return media;

      this.player.busy = true;

      return this.authenticate().then(function () {
        _this2.logger.log("[AMP AIS] Authenticated");
        return _this2.authorize();
      }).then(function (authorization) {
        _this2.logger.log("[AMP AIS] Authorized");
        media.authorization = authorization;
        _this2.player.busy = false;
        return media;
      });
    }
  }, {
    key: "request",
    value: function request(type) {
      for (var _len = arguments.length, args = Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
        args[_key - 2] = arguments[_key];
      }

      var _this3 = this;

      var event = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : type;

      return new Promise(function (resolve, reject) {
        try {
          _this3.client.assignhandler(event, function (type, resp) {
            resolve(resp);
          });
          _this3.client[type].apply(_this3.client, args);
        } catch (error) {
          reject(error);
        }
      });
    }
  }, {
    key: "bounce",
    value: function bounce() {
      return this.request("bounce");
    }
  }, {
    key: "init",
    value: function init() {
      return this.request("init");
    }
  }, {
    key: "chooser",
    value: function chooser() {
      var _this4 = this;

      return this.request("chooser").then(function (response) {
        _this4.idps = response.possible_idps = _this4.sort(response.possible_idps, "value", "display_name");
        _this4.player.busy = false;
        return new Promise(function (resolve, reject) {
          var provider = akamai.amp.AuthProvider.create;
          var logos = _this4.config.logos || {};
          var base = logos.base || "";
          var providers = [];
          var featured = null;

          for (var id in _this4.idps) {
            var idp = _this4.idps[id];
            var logo = idp.logos != null ? idp.logos[logos.key] || "" : "";
            if (logo.indexOf("http") === -1) logo = base + logo;
            providers.push(provider(id, idp.display_name, logo, idp));
          }

          var grouped = response.grouped_idps;
          if (logos.group != null && grouped != null) {
            featured = grouped.filter(function (group) {
              return group.name === logos.group;
            })[0] || {};
          }

          _this4.providers = akamai.amp.AuthProviderList.create(providers, featured.members, response.footprints, response);
          _this4.dispatch(akamai.amp.AuthEvents.CHOOSE_PROVIDER, _this4.providers);
        });
      });
    }
  }, {
    key: "identity",
    value: function identity() {
      return this.request("identity");
    }
  }, {
    key: "resourceAccess",
    value: function resourceAccess(resourceId) {
      return this.request("resourceAccess", "authz_query", resourceId);
    }
  }, {
    key: "canPreview",
    value: function canPreview() {
      var preview = this.data.preview;
      return preview && typeof preview.duration == "number";
    }
  }, {
    key: "preview",
    value: function preview() {
      return Promise.reject();
    }
  }, {
    key: "fail",
    value: function fail(event, data) {
      if (this.canPreview()) {
        return this.preview();
      } else {
        if (event != null) {
          this.dispatch(event, data);
        }
        return this.chooser();
      }
    }
  }, {
    key: "authenticate",
    value: function authenticate() {
      var _this5 = this;

      return this.bounce().then(function (response) {
        if (response.authenticated === true) {
          return _this5.init().then(function (response) {
            var key = Object.keys(response.idps)[0];
            var idp = Object.assign({ key: key }, response.idps[key]);

            if (_this5.config.logos && idp.logos) {
              idp.logo = _this5.config.logos.base + idp.logos[_this5.config.logos.key];
            }

            _this5.player.setParams({ "mvpdname": idp.name });

            // logout can be triggered by the server, so add the
            // listener here instead of waiting for the logout API call
            _this5.client.assignhandler("logout_result", function () {
              // Reload experience to restart workflow, could be returned in AuthZ
              top.location.href = top.location.href;
            });

            // TODO: idps is a depricated API property.
            _this5.idps = idp;

            _this5.provider = akamai.amp.AuthProvider(idp.key, idp.name, idp.logo, idp);
            _this5.dispatch(akamai.amp.AuthEvents.AUTHENTICATED, _this5.provider);
          });
        } else {
          return _this5.fail(akamai.amp.AuthEvents.AUTHENTICATION_FAILED, response);
        }
      });
    }
  }, {
    key: "authorized",
    value: function authorized(response) {
      this.viewerId = this.client.aisuid;
      var auth = { key: this.data.query, token: response.security_token, provider: this.provider, idps: this.idps, viewerId: this.viewerId };
      this.player.setParams({ "mvpdname": this.provider.name, viewerId: this.viewerId });
      return auth;
    }
  }, {
    key: "authorize",
    value: function authorize() {
      var _this6 = this;

      var resourceId = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.config.resourceId;

      return this.resourceAccess(resourceId).then(function (response) {
        if (response.authorization === true) {
          // TODO: This is hacky. We need a better way to determine if the asset access
          //       call needs to be made. Something other than a hard coded string.
          if (_this6.data.asset_id != null && _this6.provider.name == "comcast") {
            return _this6.assetAccess();
          } else {
            return _this6.authorized(response);
          }
        } else {
          return _this6.fail(akamai.amp.AuthEvents.AUTHORIZATION_FAILED, response);
        }
      });
    }
  }, {
    key: "assetAccess",
    value: function assetAccess() {
      var _this7 = this;

      var responseField = "ais_asset_access";
      var data = this.data;
      var query = akamai.amp.QueryString.encode({
        format: "jsonp",
        responsefield: responseField,
        network_id: data.network_id,
        namespace: data.namespace,
        asset_type: data.asset_type,
        pc_rating: data.pc_rating,
        asset_title: data.asset_title,
        asset_id: data.asset_id
      });
      var url = "//idp.securetve.com/rest/1.0/" + data.platformId + "/identity/assetAccess/" + data.resourceId + "?" + query;
      return akamai.amp.Utils.jsonp(url, responseField).then(function (response) {
        if (response.authorization === true) {
          _this7.dispatch(akamai.amp.AuthEvents.ASSET_AUTHORIZED, response);
          return _this7.authorized(response);
        } else {
          return _this7.fail(akamai.amp.AuthEvents.ASSET_AUTHORIZATION_FAILED, response);
        }
      });
    }
  }, {
    key: "sort",
    value: function sort(obj, sortType, valueName) {
      // Object sorter, used for chooser data
      var returnObj = {};
      var data = [];
      var index = 0;

      for (var key in obj) {
        data[index] = {
          key: key,
          value: obj[key][valueName] || ""
        };
        index++;
      }

      data.sort(function (a, b) {
        var valueA = sortType === "value" ? a.value.toLowerCase() : a.key.toLowercase();
        var valueB = sortType === "value" ? b.value.toLowerCase() : b.key.toLowercase();

        if (valueA < valueB) {
          // sort string ascending
          return -1;
        } else if (valueA > valueB) {
          return 1;
        } else {
          return 0; // default return value (no sorting)
        }
      });

      // Build new object based on sorted array
      return data.reduce(function (map, item) {
        map[item.key] = obj[item.key];
        return map;
      }, {});
    }
  }, {
    key: "getTarget",
    value: function getTarget() {
      var method = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "redirect";

      return this.config.responseTargets[method];
    }
  }, {
    key: "setRedirect",
    value: function setRedirect(method) {
      try {
        var devToken = /\/dev\./;
        var loc = window.top.location.href || window.top.location;
        var domain = devToken.test(loc) ? loc.replace(devToken, "/") : null;
        akamai.amp.Cookies.setCookie(this.getTarget(method), loc, 1, "/", domain);
      } catch (error) {}
    }
  }, {
    key: "launchIdp",
    value: function launchIdp(idp_platform_id) {
      var idp = idp_platform_id != null ? this.idps[idp_platform_id] : this.idps;
      var display = idp.window_display || {};
      var method = display.method != null ? display.method : "redirect";
      var target = this.getTarget(method);
      var format = idp_platform_id != null ? this.client.loginFormat(idp_platform_id, target) : this.client.logoutFormat(target);

      this.setRedirect(method);

      switch (method) {
        case "redirect":
          window.open(format, "_top"); // Full page redirect
          break;
        case "popup":
          //method = display.method || "popup"
          var width = display.width || 320;
          var height = display.height || 240;
          window.open(format, "ais_popup", "width=" + width + ",height=" + height);
      }
    }
  }, {
    key: "login",
    value: function login(idp_platform_id) {
      this.launchIdp(idp_platform_id);
    }
  }, {
    key: "logout",
    value: function logout() {
      this.launchIdp();
    }
  }]);
  return AIS;
}(akamai.amp.AuthPlugin);

akamai.amp.AMP.registerPlugin("ais", akamai.amp.Plugin.createFactory(AIS));

exports.AIS = AIS;

}((this.akamai.amp.ais = this.akamai.amp.ais || {})));
//# sourceMappingURL=Ais.js.map
