export default class class FreePreview {

  /** */
  isPreviewAvailable() {
    return this.data.preview != null && this.data.preview.duration != null
  }

  /** */
  async preview(refreshIdToken = false) {
    const duration = this.data.preview.duration * 1000
    const windowed = this.data.preview.type === "window"
    const count = `AIS_preview___${this.data.platformID}__${this.data.resourceID}`
    const delay = 100
    const expired = "PREVIEW EXPIRED"

    let remaining, startTime
    if (windowed === false) {
      startTime = localStorage.getItem(count)
      if (startTime == null) {
        startTime = 0
        localStorage.setItem(count, 0)
      }
      startTime = parseInt(startTime)
      remaining = duration - startTime

      if (remaining <= 0) {
        throw expired
      }
    }

    try {
      const tokenId = await this.requestIdToken(refreshIdToken)
      const preview = await this.requestCrossToken(tokenId)
      this.credentials(preview.token)
      this.authorized(this.token)
      if (windowed === true) {
        startTime = 0
        remaining = preview.expires - preview.issued
      }
      if (remaining <= 0) {
        throw expired
      }
      this.timer = new akamai.amp.Timer(delay, Math.ceil(remaining / delay))
      this.timer.addEventListener("timer", (event) => {
        const currentTime = event.target.time
        const remainingTime = remaining - currentTime
        if (windowed === false) {
          localStorage.setItem(count, startTime + currentTime)
        }
        this.dispatch(AISEvent.PREVIEW_TIME_REMAINING, {time: remainingTime, duration: duration})
        if (remainingTime <= 0) {
          this.timer.stop()
          // TODO: This should be a player level event
          this.dispatch(SecurityNotifications.AUTHORIZATION_EXPIRED)
        }
      });
      this.dispatch(AISEvent.PREVIEW, preview)
      this.dispatch(AISEvent.PREVIEW_TIME_REMAINING, {time: remaining, duration: duration})
    }
    catch (error) {
      this.facade.logger.error(error)
      this.authorize(true)
    }
    finally {
      this.player.busy = false
    }
  }

  /** */
  async requestGuardToken() {
    const path = `https://idp.securetve.com/rest/security/v2/platforms/${this.data.platformID}/tokens/guard`
    const json = await akamai.amp.Utils.requestJson(path)
    return json.guard_token
  }

  /** */
  async requestIdToken(refreshIdToken) {
    let token
    const tokenKey = `AIS_preview___${this.data.platformID}__response_cache__identity_token`

    if (refreshIdToken === true) {
      localStorage.removeItem(tokenKey)
    }
    else {
      token = localStorage.getItem(tokenKey)
      if (token != null) {
        return token
      }
    }

    const guard = await this.requestGuardToken()
    const km = await akamai.amp.Utils.requestJson({
      url: `https://idp.securetve.com/rest/authn/v2/platforms/${this.data.platformID}/init/fingerprint`,
      headers: {
        "Akamai-Token-Guard": guard
      }
    })
    const fingerprint = await akamai.ais.createEncryptedFingerprint(km)
    const json = await akamai.amp.Utils.requestJson({
      url: `https://idp.securetve.com/rest/authn/v2/platforms/${this.data.platformID}/tokens/id`,
      headers: {
        "Akamai-Token-Guard": guard,
        "Akamai-Authentication": `fingerprint/ob ${fingerprint}`
      }
    })

    if (json.failure_type != null) {
      throw json.failure_type
    }
    token = json.identity_token
    localStorage.setItem(tokenKey, token)
    return token
  }

  /** */
  async requestCrossToken(tokenId) {
    const path = `https://idp.securetve.com/rest/authz/v2/platforms/${this.data.platformID}/resources/${this.data.resourceID}`
    const json = akamai.amp.Utils.requestJson({
      url: path,
      headers: {
        "Akamai-Token-Id": tokenId
      }
    })

    const error = json.failure_type
    if (error != null) {
      switch (error) {
        case "INVALID_ID_TOKEN":
          return await this.preview(true)

        case "GRANTS_WINDOW_EXPIRED":
          const guard = await this.requestGuardToken()
          return await akamai.amp.Utils.requestJson({
            url: path,
            method: "POST",
            headers: {
              "Akamai-Token-Guard": guard,
              "Akamai-Token-Id": tokenId
            },
            body: `{"action":"grant_extension","attributes":{"duration":${this.data.preview.duration}}}`
          })

        default:
          throw JSON.stringify(json, null, "  ")
      }
    }

    const jwt = akamai.amp.Utils.parseJWT(json.access_token).payload.grants[this.data.resourceID]
    const preview = {
      issued: jwt.issued * 1000,
      expires: jwt.expires * 1000,
      duration: this.dadta.preview.duration
    }
    const result = await akamai.amp.Utils.requestJson({
      url: `https://idp.securetve.com/rest/authz/v2/platforms/${this.data.platformID}/tokens/crossover`,
      headers: {
        "Akamai-Token-Access": json.access_token
      }
    })

    preview.token = result.crossover_token
    return preview
  }

}
